
local CustomDecoration = ...

-- Apply building asset processor
CustomDecoration:registerAssetProcessor("models/decorations/decoration.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})
CustomDecoration:registerAssetProcessor("models/decorations/decoration3.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})
CustomDecoration:registerAssetProcessor("models/decorations/stairs.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})
CustomDecoration:registerAssetProcessor("models/decorations/stainedGlass.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})
CustomDecoration:registerAssetProcessor("models/decorations/finial.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

-- Create default building part registering function 
function registerDefaultBuildingPart(_nodePrefix)
	CustomDecoration:register({
		DataType = "BUILDING_PART",
		Id = _nodePrefix .. "_PART",
		ConstructorData = {
                    DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
                    CoreObjectPrefab = _nodePrefix .. "_PREFAB"
                }
	})
end

-- Register Main prefab nodes
CustomDecoration:registerAssetId("models/decorations/decoration.fbx/Prefab/decoration/Minor/step_1_Ladder_Tiling1Part", _PrefixAsset .. "TILING1_PREFAB")
CustomDecoration:registerAssetId("models/decorations/decoration.fbx/Prefab/decoration/Minor/step_2_Ladder_Tiling2Part", _PrefixAsset .. "TILING2_PREFAB")

--------------------------------------------------------------------------
local defaultNodePrefixList = {
	_PrefixAsset .. "TILING1",
	_PrefixAsset .. "TILING2"
}

-- Register simple building part assets
for i, nodePrefix in ipairs(defaultNodePrefixList) do
	registerDefaultBuildingPart(nodePrefix)
end

-- Register main materials
CustomDecoration:registerAssetId("models/decorations/decoration.fbx/Materials/redRoof", "STONE_GATE_V5_DECORATION_RED_ROOF_MATERIAL")
CustomDecoration:registerAssetId("models/decorations/decoration.fbx/Materials/blueRoof", "STONE_GATE_V5_DECORATION_BLUE_ROOF_MATERIAL")
CustomDecoration:registerAssetId("models/decorations/decoration.fbx/Materials/brownRoof", "STONE_GATE_V5_DECORATION_BROWN_ROOF_MATERIAL")
CustomDecoration:registerAssetId("models/decorations/decoration.fbx/Materials/greyRoof", "STONE_GATE_V5_DECORATION_GREY_ROOF_MATERIAL")
CustomDecoration:registerAssetId("models/decorations/decoration.fbx/Materials/grey2Roof", "STONE_GATE_V5_DECORATION_GREY2_ROOF_MATERIAL")

--CustomDecoration:registerAssetId("models/decorations/decoration.fbx/Materials/redRoof", _PrefixAsset .. "RED_STONE_ROOF_MATERIAL")
--CustomDecoration:registerAssetId("models/decorations/decoration.fbx/Materials/blueRoof", _PrefixAsset .. "BLUE_STONE_ROOF_MATERIAL")
--CustomDecoration:registerAssetId("models/decorations/decoration.fbx/Materials/brownRoof", _PrefixAsset .. "BROWN_STONE_ROOF_MATERIAL")
--CustomDecoration:registerAssetId("models/decorations/decoration.fbx/Materials/greyRoof", _PrefixAsset .. "GREY_STONE_ROOF_MATERIAL")
CustomDecoration:registerAssetId("models/decorations/decoration.fbx/Materials/yellowRoof", _PrefixAsset .. "YELLOW_STONE_ROOF_MATERIAL") -- to be redirected to orange church tiles ?

-- Create default minor decoration part registering function 
function registerDefaultDecorationPart(_nameFbxBase, _nameFbxModel, _nameFbx, _nameAsset, _resourceCost, _buildingPartType)
    CustomDecoration:registerAssetId("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/" .. _nameFbx .. "Part", _PrefixAsset ..  _nameAsset .. "_PREFAB")

    function registerDecorationPart(_prefixAssetTop, _moverType, _resourceCost2)
        CustomDecoration:register({
        	DataType = "BUILDING_PART",
	        Id = _prefixAssetTop .. _nameAsset .. "_PART",
	        Name = _prefixAssetTop .. _nameAsset .. "_NAME",
	        Description = _prefixAssetTop .. _nameAsset .. "_DESC",
	        Category = "DECORATION",
	        ConstructorData = {
		    DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		    CoreObjectPrefab = _PrefixAsset .. _nameAsset .. "_PREFAB",
                    IsPreviewGroundVisible = false
	        },
	        Cost = {
		    UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
	            },
		    RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			_resourceCost2
		    }
	        }
        })
    end

    registerDecorationPart(_PrefixAsset .. "TOP_", "BUILDING_PART_MOVER", { Resource = "STONE", Quantity = 0 })
    registerDecorationPart("STONE_GATE_V5_DECORATION_", "BUILDING_PART_MOVER_INSTANCE", _resourceCost)

    -- Register LEAD_WIRE_ALIGN_COMP component (no effects for STONE_GATE_V5_DECORATION)
    CustomDecoration:registerPrefabComponent("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/" .. _nameFbx .. "Part", {
	DataType = _PrefixAsset .. "LEAD_WIRE_ALIGN_COMP",
	Enabled = true
    })

    CustomDecoration:registerPrefabComponent("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/" .. _nameFbx .. "Part", {
	DataType = "COMP_BUILDING_PART",
	BuildingPartType = _buildingPartType,
  	HasBuildingZone = true,
	BuildingZone = { 0, 0 }
    })

-- Register Main prefab nodes
    CustomDecoration:registerAssetId("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/step_0_Ladder_" .. _nameFbx .. "_RootPart", _PrefixAsset .. _nameAsset .. "_ROOT_PREFAB")

-- Register the root part
    CustomDecoration:register({
	DataType = "BUILDING_PART",
	Id = _PrefixAsset .. _nameAsset .. "_ROOT_PART",
	Name = _PrefixAsset .. _nameAsset .. "_ROOT_NAME",
	Description = _PrefixAsset .. _nameAsset .. "_ROOT_DESC",
	Category = "DECORATION",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = _PrefixAsset .. _nameAsset .. "_ROOT_PREFAB",
		EndPart = _PrefixAsset .. "TOP_" .. _nameAsset .. "_PART",
		FillerList = {
			_PrefixAsset .. "TILING2_PART"
                },
		BasementFillerList = {
			_PrefixAsset .. "TILING1_PART"
         	},
		MinimumScale = 0,
		IsVertical = true
	}
    })
end

registerDefaultDecorationPart("decoration", "decoration/Minor", "SFenetre", "SFENETRE", { Resource = "STONE", Quantity = 1 }, "MINOR")
registerDefaultDecorationPart("decoration", "decoration/Minor", "LFenetre", "LFENETRE", { Resource = "STONE", Quantity = 1 }, "MINOR")
registerDefaultDecorationPart("decoration", "decoration/Minor", "PFenetre", "PFENETRE", { Resource = "STONE", Quantity = 1 }, "MINOR")
registerDefaultDecorationPart("decoration", "decoration/Minor", "ArrowSlit", "ARROWSLIT", { Resource = "STONE", Quantity = 1 }, "MINOR")
registerDefaultDecorationPart("decoration", "decoration/Minor", "Lucarne", "LUCARNE", { Resource = "WOOD", Quantity = 1 }, "MINOR")
registerDefaultDecorationPart("decoration", "decoration/Minor", "Lucarne2", "LUCARNE2", { Resource = "WOOD", Quantity = 1 }, "MINOR") --kept for compatibility
registerDefaultDecorationPart("decoration", "decoration/Minor", "Lucarne3", "LUCARNE3", { Resource = "WOOD", Quantity = 1 }, "MINOR") --kept for compatibility
registerDefaultDecorationPart("decoration", "decoration/Minor", "Lucarne4", "LUCARNE4", { Resource = "WOOD", Quantity = 1 }, "MINOR") --kept for compatibility
registerDefaultDecorationPart("decoration", "decoration/Minor", "LargeLucarne", "LARGE_LUCARNE", { Resource = "WOOD", Quantity = 1 }, "MINOR")
registerDefaultDecorationPart("decoration", "decoration/Minor", "Balcony", "BALCONY", { Resource = "STONE", Quantity = 2 }, "MINOR")
registerDefaultDecorationPart("decoration", "decoration/Minor", "Balcony2", "BALCONY2", { Resource = "STONE", Quantity = 2 }, "MINOR") --kept for compatibility
registerDefaultDecorationPart("decoration", "decoration/Minor", "Balcony3", "BALCONY3", { Resource = "STONE", Quantity = 2 }, "MINOR") --kept for compatibility
registerDefaultDecorationPart("decoration", "decoration/Minor", "Balcony4", "BALCONY4", { Resource = "STONE", Quantity = 2 }, "MINOR") --kept for compatibility
registerDefaultDecorationPart("decoration", "decoration/Minor", "Chimney", "CHIMNEY", { Resource = "STONE", Quantity = 1 }, "MINOR")

-- Register air vent particle system (smoke)
    CustomDecoration:registerAssetId("models/decorations/decoration.fbx/Prefab/decoration/Minor/ChimneyPart/SmokeEmitter", "CUSTOM_CHIMNEY_SMOKE_EMITTER_PREFAB")

    CustomDecoration:registerPrefabComponent("models/decorations/decoration.fbx/Prefab/decoration/Minor/ChimneyPart", {
	DataType = "COMP_BUILDING_PART",
	FeedbackComponentListToActivate = {
                 { "CUSTOM_CHIMNEY_SMOKE_EMITTER_PREFAB", "COMP_PARTICLE_EMITTER_TOGGLE" }
	}
    })

    CustomDecoration:registerPrefabComponent("models/decorations/decoration.fbx/Prefab/decoration/Minor/ChimneyPart/SmokeEmitter", {
	DataType = "COMP_PARTICLE_EMITTER",
	ParticleSystem = "PARTICLE_SYSTEM_HOUSING_SMOKE",
	IsPlaying = true,
	IsEmitting = true
    })

    CustomDecoration:registerPrefabComponent("models/decorations/decoration.fbx/Prefab/decoration/Minor/ChimneyPart/SmokeEmitter", {
	DataType = "COMP_PARTICLE_EMITTER_TOGGLE",
	Enabled = false
    })

registerDefaultDecorationPart("decoration", "decoration/Minor", "Tourelle", "TURRET", { Resource = "STONE", Quantity = 2 }, "MINOR")
registerDefaultDecorationPart("decoration", "decoration/Minor", "Tourelle2", "TURRET2", { Resource = "STONE", Quantity = 2 }, "MINOR") --kept for compatibility
registerDefaultDecorationPart("decoration", "decoration/Minor", "Tourelle3", "TURRET3", { Resource = "STONE", Quantity = 2 }, "MINOR") --kept for compatibility
registerDefaultDecorationPart("decoration", "decoration/Minor", "ChimneyB", "CHIMNEY_B", { Resource = "STONE", Quantity = 1 }, "MINOR")
registerDefaultDecorationPart("decoration3", "commonDecoration", "roundWindow2", "STONE_ROUND_WINDOW", { Resource = "STONE", Quantity = 1 }, "MINOR")
registerDefaultDecorationPart("finial", "decoration/Minor", "Finial1", "FINIAL1", { Resource = "IRON", Quantity = 1 }, "MAJOR")
registerDefaultDecorationPart("finial", "decoration/Minor", "Finial2", "FINIAL2", { Resource = "IRON", Quantity = 1 }, "MAJOR")
registerDefaultDecorationPart("finial", "decoration/Minor", "Finial3", "FINIAL3", { Resource = "IRON", Quantity = 1 }, "MAJOR")
registerDefaultDecorationPart("decoration", "decoration/Minor", "window9", "WOODEN_WINDOW_9", { Resource = "WOOD", Quantity = 1 }, "MINOR")

-- Create stained glass minor decoration part registering function 
function registerStainedGlassMinorDecorationPart(_nameFbxBase, _nameFbxModel, _nameFbx, _nameAsset, _stoneCost)
    CustomDecoration:registerAssetId("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/" .. _nameFbx .. "Part", _PrefixAsset ..  _nameAsset .. "_PREFAB")
    CustomDecoration:registerAssetId("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/" .. _nameFbx .. "WsPart", _PrefixAsset ..  _nameAsset .. "_WS_PREFAB")

    function registerDecorationPart(_prefixAssetTop, _moverType, _stoneCost2, _stoneColor)
        CustomDecoration:register({
        	DataType = "BUILDING_PART",
	        Id = _prefixAssetTop .. _nameAsset .. "_PART",
	        Name = _prefixAssetTop .. _nameAsset .. "_NAME",
	        Description = _prefixAssetTop .. _nameAsset .. "_DESC",
	        Category = "DECORATION",
	        ConstructorData = {
		    DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		    CoreObjectPrefab = _PrefixAsset .. _nameAsset .. _stoneColor .. "_PREFAB",
                    IsPreviewGroundVisible = false
	        },
	        Cost = {
		    UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
	            },
		    RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "GLASS", Quantity = _stoneCost2 }
		    }
	        }
        })
    end

    registerDecorationPart(_PrefixAsset .. "TOP_", "BUILDING_PART_MOVER", 0, "")
    registerDecorationPart("CHURCH_V1_DECORATION_", "BUILDING_PART_MOVER_INSTANCE", _stoneCost, "") -- with church corner stone

    CustomDecoration:registerPrefabComponent("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/" .. _nameFbx .. "Part", {
	DataType = "COMP_BUILDING_PART",
	BuildingPartType = "MINOR"
    })

    registerDecorationPart("STONE_GATE_V5_DECORATION_", "BUILDING_PART_MOVER_INSTANCE", _stoneCost, "_WS") -- with white stones

    CustomDecoration:registerPrefabComponent("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/" .. _nameFbx .. "WsPart", {
	DataType = "COMP_BUILDING_PART",
	BuildingPartType = "MINOR"
    })

    -- Register LEAD_WIRE_ALIGN_COMP component (no effects for STONE_GATE_V5_DECORATION)
    CustomDecoration:registerPrefabComponent("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/" .. _nameFbx .. "Part", {
	DataType = _PrefixAsset .. "LEAD_WIRE_ALIGN_COMP",
	Enabled = true
    })

    -- Register LEAD_WIRE_ALIGN_COMP component (no effects for STONE_GATE_V5_DECORATION)
    CustomDecoration:registerPrefabComponent("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/" .. _nameFbx .. "WsPart", {
	DataType = _PrefixAsset .. "LEAD_WIRE_ALIGN_COMP",
	Enabled = true
    })

-- Register Main prefab nodes
    CustomDecoration:registerAssetId("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/step_0_Ladder_" .. _nameFbx .. "_RootPart", _PrefixAsset .. _nameAsset .. "_ROOT_PREFAB")

-- Register the root part
    CustomDecoration:register({
	DataType = "BUILDING_PART",
	Id = _PrefixAsset .. _nameAsset .. "_ROOT_PART",
	Name = _PrefixAsset .. _nameAsset .. "_ROOT_NAME",
	Description = _PrefixAsset .. _nameAsset .. "_ROOT_DESC",
	Category = "DECORATION",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = _PrefixAsset .. _nameAsset .. "_ROOT_PREFAB",
		EndPart = _PrefixAsset .. "TOP_" .. _nameAsset .. "_PART",
		FillerList = {
			_PrefixAsset .. "TILING2_PART"
                },
		BasementFillerList = {
			_PrefixAsset .. "TILING1_PART"
         	},
		MinimumScale = 0,
		IsVertical = true
	}
    })

-- Override building part components properties (generated by the building asset processor) to add building zones
    CustomDecoration:registerPrefabComponent("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/step_0_Ladder_" .. _nameFbx .. "_RootPart", {
	DataType = "COMP_BUILDING_PART",
	BuildingPartType = "MINOR"
    })
end

registerStainedGlassMinorDecorationPart("stainedGlass", "commonDecoration", "stainedGlassWindow1", "STAINED_GLASS_WINDOW_1", 10)
registerStainedGlassMinorDecorationPart("stainedGlass", "commonDecoration", "StainedGlass1", "STAINED_GLASS_1", 10)
registerStainedGlassMinorDecorationPart("stainedGlass", "commonDecoration", "StainedGlass2", "STAINED_GLASS_2", 10)
registerStainedGlassMinorDecorationPart("stainedGlass", "commonDecoration", "StainedGlass3", "STAINED_GLASS_3", 10)
registerStainedGlassMinorDecorationPart("stainedGlass", "commonDecoration", "StainedGlass4", "STAINED_GLASS_4", 10)
registerStainedGlassMinorDecorationPart("stainedGlass", "commonDecoration", "StainedGlass8", "STAINED_GLASS_8", 10)
registerStainedGlassMinorDecorationPart("stainedGlass", "commonDecoration", "Splendor2", "SPLENDOR_2", 10)
registerStainedGlassMinorDecorationPart("stainedGlass", "commonDecoration", "PStainedGlass1", "P_STAINED_GLASS_1", 7)
registerStainedGlassMinorDecorationPart("stainedGlass", "commonDecoration", "StainedGlassTall1", "STAINED_GLASS_TALL_1", 7)
registerStainedGlassMinorDecorationPart("stainedGlass", "commonDecoration", "StainedGlassTall2", "STAINED_GLASS_TALL_2", 7)

-- Create specific decoration part registering function 
function registerDefaultMajorDecorationPart(_nameFbx, _nameAsset, _stoneCost)
    CustomDecoration:registerAssetId("models/decorations/decoration.fbx/Prefab/decoration/Minor/" .. _nameFbx .. "Part", _PrefixAsset ..  _nameAsset .. "_PREFAB")

    function registerDecorationPart(_prefixAssetTop, _moverType, _stoneCost2)
        CustomDecoration:register({
        	DataType = "BUILDING_PART",
	        Id = _prefixAssetTop .. _nameAsset .. "_PART",
	        Name = _prefixAssetTop .. _nameAsset .. "_NAME",
	        Description = _prefixAssetTop .. _nameAsset .. "_DESC",
	        Category = "DECORATION",
	        ConstructorData = {
		    DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		    CoreObjectPrefab = _PrefixAsset .. _nameAsset .. "_PREFAB",
                    IsPreviewGroundVisible = false
	        },
	        Cost = {
		    UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
	            },
		    RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = _stoneCost2 }
		    }
	        }
        })
    end

    registerDecorationPart(_PrefixAsset .. "TOP_", "BUILDING_PART_MOVER", 0)
--    registerDecorationPart("STONE_GATE_V5_DECORATION_", "BUILDING_PART_MOVER_INSTANCE")

    CustomDecoration:registerPrefabComponent("models/decorations/decoration.fbx/Prefab/decoration/Minor/" .. _nameFbx .. "Part", {
	DataType = "COMP_BUILDING_PART",
--	BuildingPartType = "MINOR"
    })

    -- Register LEAD_WIRE_ALIGN_COMP component (no effects for STONE_GATE_V5_DECORATION)
    CustomDecoration:registerPrefabComponent("models/decorations/decoration.fbx/Prefab/decoration/Minor/" .. _nameFbx .. "Part", {
	DataType = _PrefixAsset .. "LEAD_WIRE_ALIGN_COMP",
	Enabled = true
    })

-- Register Main prefab nodes
    CustomDecoration:registerAssetId("models/decorations/decoration.fbx/Prefab/decoration/Minor/step_0_Ladder_" .. _nameFbx .. "_RootPart", _PrefixAsset .. _nameAsset .. "_ROOT_PREFAB")

-- Register the root part
    CustomDecoration:register({
	DataType = "BUILDING_PART",
	Id = _PrefixAsset .. _nameAsset .. "_ROOT_PART",
	Name = _PrefixAsset .. _nameAsset .. "_ROOT_NAME",
	Description = _PrefixAsset .. _nameAsset .. "_ROOT_DESC",
	Category = "DECORATION",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = _PrefixAsset .. _nameAsset .. "_ROOT_PREFAB",
		EndPart = _PrefixAsset .. "TOP_" .. _nameAsset .. "_PART",
		FillerList = {
			_PrefixAsset .. "TILING2_PART"
                },
		BasementFillerList = {
			_PrefixAsset .. "TILING1_PART"
         	},
		MinimumScale = 0,
		IsVertical = true
	}
    })
end

registerDefaultMajorDecorationPart("DoorA", "DOOR_A", 1)
registerDefaultMajorDecorationPart("DoorB", "DOOR_B", 1)

-- Create wooden decoration part registering function 
CustomDecoration:registerAssetProcessor("models/decorations/woodenDecoration.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})
CustomDecoration:registerAssetProcessor("models/decorations/woodenDecoration2.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

-- Register main materials
CustomDecoration:registerAssetId("models/decorations/woodenDecoration.fbx/Materials/toitRouge", _PrefixAsset .. "RED_WOODEN_ROOF_MATERIAL")
CustomDecoration:registerAssetId("models/decorations/woodenDecoration.fbx/Materials/toitBleu", _PrefixAsset .. "BLUE_WOODEN_ROOF_MATERIAL")
CustomDecoration:registerAssetId("models/decorations/woodenDecoration.fbx/Materials/toitJaune", _PrefixAsset .. "YELLOW_WOODEN_ROOF_MATERIAL")
CustomDecoration:registerAssetId("models/decorations/woodenDecoration.fbx/Materials/toitCarbone", _PrefixAsset .. "GREY_WOODEN_ROOF_MATERIAL")
CustomDecoration:registerAssetId("models/decorations/woodenDecoration.fbx/Materials/toitBrun", _PrefixAsset .. "BROWN_WOODEN_ROOF_MATERIAL")
CustomDecoration:registerAssetId("models/decorations/woodenDecoration2.fbx/Materials/toitRouge", _PrefixAsset .. "RED_WOODEN2_ROOF_MATERIAL")
CustomDecoration:registerAssetId("models/decorations/woodenDecoration2.fbx/Materials/toitBleu", _PrefixAsset .. "BLUE_WOODEN2_ROOF_MATERIAL")
CustomDecoration:registerAssetId("models/decorations/woodenDecoration2.fbx/Materials/toitJaune", _PrefixAsset .. "YELLOW_WOODEN2_ROOF_MATERIAL")
CustomDecoration:registerAssetId("models/decorations/woodenDecoration2.fbx/Materials/toitCarbone", _PrefixAsset .. "GREY_WOODEN2_ROOF_MATERIAL")
CustomDecoration:registerAssetId("models/decorations/woodenDecoration2.fbx/Materials/toitBrun", _PrefixAsset .. "BROWN_WOODEN2_ROOF_MATERIAL")

function registerDefaultWoodenDecorationPart(_nameFbxBase, _nameFbxModel, _nameFbx, _nameAsset, _woodCost, _buildingPartType)
    CustomDecoration:registerAssetId("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/".. _nameFbxModel .. "/" .. _nameFbx .. "Part", _PrefixAsset ..  _nameAsset .. "_PREFAB")

    function registerDecorationPart(_prefixAssetTop, _moverType, _woodCost2)
        CustomDecoration:register({
        	DataType = "BUILDING_PART",
	        Id = _prefixAssetTop .. _nameAsset .. "_PART",
	        Name = _prefixAssetTop .. _nameAsset .. "_NAME",
	        Description = _prefixAssetTop .. _nameAsset .. "_DESC",
	        Category = "DECORATION",
	        ConstructorData = {
		    DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		    CoreObjectPrefab = _PrefixAsset .. _nameAsset .. "_PREFAB",
                    IsPreviewGroundVisible = false
	        },
	        Cost = {
		    UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
	            },
		    RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "WOOD", Quantity = _woodCost2 }
		    }
	        }
        })
    end

    registerDecorationPart(_PrefixAsset .. "TOP_", "BUILDING_PART_MOVER", 0) -- wood cost is forced to 0
    registerDecorationPart("STONE_GATE_V5_DECORATION_", "BUILDING_PART_MOVER_INSTANCE", _woodCost)

    CustomDecoration:registerPrefabComponent("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/".. _nameFbxModel .. "/" .. _nameFbx .. "Part", {
	DataType = "COMP_BUILDING_PART",
	BuildingPartType = _buildingPartType,
  	HasBuildingZone = true,
	BuildingZone = { 0, 0 }
    })

    -- Register LEAD_WIRE_ALIGN_COMP component (no effects for STONE_GATE_V5_DECORATION)
    CustomDecoration:registerPrefabComponent("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/" .. _nameFbx .. "Part", {
	DataType = _PrefixAsset .. "LEAD_WIRE_ALIGN_COMP",
	Enabled = true
    })

-- Register Main prefab nodes
    CustomDecoration:registerAssetId("models/decorations/" .. _nameFbxBase .. ".fbx/Prefab/" .. _nameFbxModel .. "/step_0_Ladder_" .. _nameFbx .. "_RootPart", _PrefixAsset .. _nameAsset .. "_ROOT_PREFAB")

-- Register the root part
    CustomDecoration:register({
	DataType = "BUILDING_PART",
	Id = _PrefixAsset .. _nameAsset .. "_ROOT_PART",
	Name = _PrefixAsset .. _nameAsset .. "_ROOT_NAME",
	Description = _PrefixAsset .. _nameAsset .. "_ROOT_DESC",
	Category = "DECORATION",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = _PrefixAsset .. _nameAsset .. "_ROOT_PREFAB",
		EndPart = _PrefixAsset .. "TOP_" .. _nameAsset .. "_PART",
		FillerList = {
			_PrefixAsset .. "TILING2_PART"
                },
		BasementFillerList = {
			_PrefixAsset .. "TILING1_PART"
         	},
		MinimumScale = 0,
		IsVertical = true
	}
    })
end

registerDefaultWoodenDecorationPart("woodenDecoration", "woodenDecoration", "door1", "WOODEN_DOOR_1", 1, "MAJOR")
registerDefaultWoodenDecorationPart("woodenDecoration", "woodenDecoration", "door2", "WOODEN_DOOR_2", 1, "MAJOR")
registerDefaultWoodenDecorationPart("woodenDecoration", "woodenDecoration", "door3", "WOODEN_DOOR_3", 1, "MAJOR")
registerDefaultWoodenDecorationPart("woodenDecoration", "woodenDecoration", "door4", "WOODEN_DOOR_4", 1, "MAJOR")
registerDefaultWoodenDecorationPart("woodenDecoration", "woodenDecoration", "door5", "WOODEN_DOOR_5", 1, "MAJOR")
registerDefaultWoodenDecorationPart("woodenDecoration", "woodenDecoration", "door6", "WOODEN_DOOR_6", 1, "MAJOR")
registerDefaultWoodenDecorationPart("woodenDecoration", "woodenDecoration", "window1", "WOODEN_WINDOW_1", 1, "MINOR")
registerDefaultWoodenDecorationPart("woodenDecoration2", "woodenDecoration", "window2", "WOODEN_WINDOW_2", 1, "MAJOR")
registerDefaultWoodenDecorationPart("woodenDecoration2", "woodenDecoration", "window3", "WOODEN_WINDOW_3", 1, "MINOR")
registerDefaultWoodenDecorationPart("woodenDecoration2", "woodenDecoration", "window4", "WOODEN_WINDOW_4", 1, "MAJOR")
registerDefaultWoodenDecorationPart("woodenDecoration2", "woodenDecoration", "window5", "WOODEN_WINDOW_5", 1, "MAJOR")
registerDefaultWoodenDecorationPart("woodenDecoration2", "woodenDecoration", "window6", "WOODEN_WINDOW_6", 1, "MAJOR")
registerDefaultWoodenDecorationPart("woodenDecoration2", "woodenDecoration", "window7", "WOODEN_WINDOW_7", 1, "MINOR")
registerDefaultWoodenDecorationPart("woodenDecoration2", "woodenDecoration", "window8", "WOODEN_WINDOW_8", 1, "MINOR")
registerDefaultWoodenDecorationPart("decoration3", "commonDecoration", "roundWindow1", "WOODEN_ROUND_WINDOW", 1, "MINOR")
registerDefaultWoodenDecorationPart("stairs", "commonDecoration", "stair1", "WOODEN_STAIRS_1", 2, "MAJOR")


