local CustomDecoration = ...

_PrefixAsset = "CUSTOM_DECORATION_V1_"

-- Register all stone gate set building parts and their properties
CustomDecoration:dofile("scripts/compLeadWire.lua")
CustomDecoration:dofile("scripts/leadWire.lua")
CustomDecoration:dofile("scripts/compLeadWireAlign.lua")
CustomDecoration:dofile("scripts/decoration.lua")

-- Apply building asset processor
CustomDecoration:registerAssetProcessor("models/decorations/core.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

CustomDecoration:registerAssetId("models/decorations/core.fbx/Prefab/decoration/CoreBuildingPart", _PrefixAsset .. "CORE_BUILDING_PREFAB")

-- Register the Core part
CustomDecoration:register({
	DataType = "BUILDING_PART",
	Id = _PrefixAsset .. "CORE_BUILDING_PART",
	Name = _PrefixAsset .. "CORE_BUILDING_NAME",
	Description = _PrefixAsset .. "CORE_BUILDING_DESC",
	Category = "CORE",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = _PrefixAsset .. "CORE_BUILDING_PREFAB"
	},
        IsVisibleWhenBuilt = false
})

local myMonument = {
    Id = _PrefixAsset .. "MONUMENT"
}

_StoneBuildingPartList = {
			Name = _PrefixAsset .. "STONE_MONUMENT_PARTSETLIST_NAME",
	                BuildingPartList = {
		            _PrefixAsset .. "SFENETRE_ROOT_PART",
		            _PrefixAsset .. "LFENETRE_ROOT_PART",
		            _PrefixAsset .. "PFENETRE_ROOT_PART",
		            _PrefixAsset .. "STONE_ROUND_WINDOW_ROOT_PART",
		            _PrefixAsset .. "ARROWSLIT_ROOT_PART",
		            _PrefixAsset .. "BALCONY_ROOT_PART",
--		            _PrefixAsset .. "BALCONY2_ROOT_PART",
--		            _PrefixAsset .. "BALCONY3_ROOT_PART",
--		            _PrefixAsset .. "BALCONY4_ROOT_PART",
		            _PrefixAsset .. "CHIMNEY_ROOT_PART",
		            _PrefixAsset .. "CHIMNEY_B_ROOT_PART",
		            _PrefixAsset .. "LUCARNE_ROOT_PART",
--		            _PrefixAsset .. "LUCARNE2_ROOT_PART",
		            _PrefixAsset .. "LUCARNE3_ROOT_PART", -- whith white chalk wall
--		            _PrefixAsset .. "LUCARNE4_ROOT_PART",
		            _PrefixAsset .. "LARGE_LUCARNE_ROOT_PART",
		            _PrefixAsset .. "TURRET_ROOT_PART",
--		            _PrefixAsset .. "TURRET2_ROOT_PART",
--		            _PrefixAsset .. "TURRET3_ROOT_PART",
		            _PrefixAsset .. "DOOR_A_ROOT_PART",
		            _PrefixAsset .. "DOOR_B_ROOT_PART"
                        }  
}
_WoodenBuildingPartList = {
			Name = _PrefixAsset .. "WOODEN_MONUMENT_PARTSETLIST_NAME",
	                BuildingPartList = {
		            _PrefixAsset .. "WOODEN_DOOR_1_ROOT_PART",
--		            _PrefixAsset .. "WOODEN_DOOR_2_ROOT_PART",
		            _PrefixAsset .. "WOODEN_DOOR_3_ROOT_PART",
		            _PrefixAsset .. "WOODEN_DOOR_4_ROOT_PART",
--		            _PrefixAsset .. "WOODEN_DOOR_5_ROOT_PART",
--		            _PrefixAsset .. "WOODEN_DOOR_6_ROOT_PART",
		            _PrefixAsset .. "WOODEN_WINDOW_1_ROOT_PART",
--		            _PrefixAsset .. "WOODEN_WINDOW_2_ROOT_PART",
		            _PrefixAsset .. "WOODEN_WINDOW_3_ROOT_PART",
		            _PrefixAsset .. "WOODEN_WINDOW_4_ROOT_PART",
--		            _PrefixAsset .. "WOODEN_WINDOW_5_ROOT_PART",
--		            _PrefixAsset .. "WOODEN_WINDOW_6_ROOT_PART",
		            _PrefixAsset .. "WOODEN_WINDOW_7_ROOT_PART",
		            _PrefixAsset .. "WOODEN_WINDOW_8_ROOT_PART",
		            _PrefixAsset .. "WOODEN_WINDOW_9_ROOT_PART",
		            _PrefixAsset .. "WOODEN_ROUND_WINDOW_ROOT_PART",
		            _PrefixAsset .. "WOODEN_STAIRS_1_ROOT_PART"
                        }  
}
_FinialBuildingPartList = {
			Name = _PrefixAsset .. "IRON_MONUMENT_PARTSETLIST_NAME",
	                BuildingPartList = {
                            _PrefixAsset .. "FINIAL1_ROOT_PART",
		            _PrefixAsset .. "FINIAL2_ROOT_PART",
		            _PrefixAsset .. "FINIAL3_ROOT_PART"
                        }   
}
_StainedGlassBuildingPartList = {
			Name = _PrefixAsset .. "STAINED_GLASS_PARTSETLIST_NAME",
	                BuildingPartList = {
                            _PrefixAsset .. "STAINED_GLASS_WINDOW_1_ROOT_PART",
		            _PrefixAsset .. "STAINED_GLASS_1_ROOT_PART",
		            _PrefixAsset .. "STAINED_GLASS_2_ROOT_PART",
		            _PrefixAsset .. "STAINED_GLASS_3_ROOT_PART",
		            _PrefixAsset .. "STAINED_GLASS_4_ROOT_PART",
		            _PrefixAsset .. "STAINED_GLASS_8_ROOT_PART",
		            _PrefixAsset .. "SPLENDOR_2_ROOT_PART",
		            _PrefixAsset .. "P_STAINED_GLASS_1_ROOT_PART",
		            _PrefixAsset .. "STAINED_GLASS_TALL_1_ROOT_PART",
		            _PrefixAsset .. "STAINED_GLASS_TALL_2_ROOT_PART"
                        }   
}

if (foundation.getGameVersion == nil or version.cmp(foundation.getGameVersion(), "1.6") < 0) then
    CustomDecoration:log("Hello World: version 1.5")
    return
end

CustomDecoration:log("Hello World: version " .. foundation.getGameVersion())
myMonument.DataType = "BUILDING"
myMonument.AssetCoreBuildingPart = _PrefixAsset .. "CORE_BUILDING_PART"
myMonument.BuildingPartSetList = {
		{
			Name = _PrefixAsset .. "LEAD_WIRE_PARTSETLIST_NAME",
	                BuildingPartList = {
		            _PrefixAsset .. "LEAD_WIRE_ROOT_PART"
                        }
                },
		_StoneBuildingPartList,
		_WoodenBuildingPartList,
		_FinialBuildingPartList,
		_StainedGlassBuildingPartList 
    }
-- Currently all the BuildinZone are set to { 0, 0 } and ignored in 1.6.6,
-- so there is no need to refactor them
CustomDecoration:registerEnumValue ("BUILDING_PART_TYPE", "DECORATION")

myMonument.Name = "CUSTOM_DECORATION_V1_MONUMENT_NAME"
myMonument.Description = "CUSTOM_DECORATION_V1_MONUMENT_DESC"
myMonument.BuildingType = "DECORATION"
myMonument.MaterialSetList = {
            {
                SetName = _PrefixAsset .. "RED_ROOF", -- default materials
                MaterialList = {
                    "STONE_GATE_V5_DECORATION_RED_ROOF_MATERIAL",
                    _PrefixAsset .. "RED_WOODEN_ROOF_MATERIAL",
                    _PrefixAsset .. "RED_WOODEN2_ROOF_MATERIAL"
               }
            },
            {
                SetName = _PrefixAsset .. "BLUE_ROOF",
                MaterialList = {
                    "STONE_GATE_V5_DECORATION_BLUE_ROOF_MATERIAL",
                    _PrefixAsset .. "BLUE_WOODEN_ROOF_MATERIAL",
                    _PrefixAsset .. "BLUE_WOODEN2_ROOF_MATERIAL"
                }
            },
            {
                SetName = _PrefixAsset .. "BROWN_ROOF",
                MaterialList = {
                    "STONE_GATE_V5_DECORATION_BROWN_ROOF_MATERIAL",
                    _PrefixAsset .. "BROWN_WOODEN_ROOF_MATERIAL",
                    _PrefixAsset .. "BROWN_WOODEN2_ROOF_MATERIAL"
                }
            },
            {
                SetName = _PrefixAsset .. "GREY_ROOF",
                MaterialList = {
                    "STONE_GATE_V5_DECORATION_GREY_ROOF_MATERIAL",
                    _PrefixAsset .. "GREY_WOODEN_ROOF_MATERIAL",
                    _PrefixAsset .. "GREY_WOODEN2_ROOF_MATERIAL"
                }
            },
            {
                SetName = _PrefixAsset .. "YELLOW_ROOF",
                MaterialList = {
                    _PrefixAsset .. "YELLOW_STONE_ROOF_MATERIAL",
                    _PrefixAsset .. "YELLOW_WOODEN_ROOF_MATERIAL",
                    _PrefixAsset .. "YELLOW_WOODEN2_ROOF_MATERIAL"
                }
            }
}
myMonument.IsEditable = true

-- Register the CustomDecoration monument
CustomDecoration:register(myMonument)

CustomDecoration:override({
    Id = "MONUMENT_CHURCH",
    BuildingPartSetList = {
                Action = "APPEND",
		{
			Name = "CHURCH_ADDITION_NAME",
                	BuildingPartList = {
                            "CHURCH_V1_DECORATION_STAINED_GLASS_WINDOW_1_PART",
                            "CHURCH_V1_DECORATION_STAINED_GLASS_1_PART",
                            "CHURCH_V1_DECORATION_STAINED_GLASS_2_PART",
                            "CHURCH_V1_DECORATION_STAINED_GLASS_3_PART",
                            "CHURCH_V1_DECORATION_STAINED_GLASS_4_PART",
                            "CHURCH_V1_DECORATION_STAINED_GLASS_8_PART",
                            "CHURCH_V1_DECORATION_SPLENDOR_2_PART",
                            "CHURCH_V1_DECORATION_P_STAINED_GLASS_1_PART",
                            "CHURCH_V1_DECORATION_STAINED_GLASS_TALL_1_PART",
                            "CHURCH_V1_DECORATION_STAINED_GLASS_TALL_2_PART"
                        }
                }
    }
})

